==> fillets-ng-data_0.7.1.orig.tar.gz: fillets-ng-data-0.7.1/script/chest/dialogs_de.lua <==

dialogId("tru-v-nasly", "font_big", "So we have finally found it.")
dialogStr("Haben wir sie endlich gefunden.")


dialogId("tru-m-co", "font_small", "What?")
dialogStr("Was?")


dialogId("tru-v-poklad", "font_big", "Captain Silver`s treasure, of course.")
dialogStr("Na Kapitän Silvers Schatz!")


dialogId("tru-v-gral", "font_big", "The Holy Grail, of course.")
dialogStr("Na den heiligen Gral!")


dialogId("tru-v-vkupe", "font_big", "It`s neatly in one place: the treasure and the Grail.")
dialogStr("Alles schön auf einem Haufen: der Schatz und der Gral.")


dialogId("tru-m-zrada", "font_small", "I think it`s much too easy to be true.")
dialogStr("Ich glaube, das ist zu einfach, um war zu sein.")


dialogId("tru-m-oznamit", "font_small", "I think that if it really was our goal, the game would let the player know.")
dialogStr("Ich denke, wenn das wirklich unser Ziel wäre, würde das Programm es den Spieler wissen lassen.")


dialogId("tru-v-stacit", "font_big", "But I have let them know. That could be enough.")
dialogStr("Aber ich habe es ihn wissen lassen. Das könnte reichen.")


dialogId("tru-m-zpochybnit", "font_small", "But I have casted doubts on it. This could confuse them.")
dialogStr("Aber ich habe es angezweifelt. Das könnte ihn durcheinanderbringen.")


dialogId("tru-v-nejspis", "font_big", "Well, all right. PROBABLY this is not what we are looking for.")
dialogStr("Hmm, na gut. WAHRSCHEINLICH ist das nicht, wonach wir suchen.")


dialogId("tru-m-nejistota", "font_small", "That's better. There remains a bit of uncertainty.")
dialogStr("So ist es besser. Das hinterlässt eine bisschen Unsicherheit.")


dialogId("tru-m-truhla0", "font_small", "Couldn`t we close that chest?")
dialogStr("Können wir die Truhe nicht zumachen?")


dialogId("tru-m-truhla1", "font_small", "What if we try to close that chest?")
dialogStr("Wollen wir versuchen, die Truhe zu schließen?")


dialogId("tru-v-truhla0", "font_big", "It would be much easier with the chest closed.")
dialogStr("Mit der geschlossenen Truhe wäre es viel einfacher.")


dialogId("tru-v-truhla1", "font_big", "Try to push its lid.")
dialogStr("Versuch mal, den Deckel zu bewegen.")


dialogId("tru-m-vzit0", "font_small", "Won`t we take something with us?")
dialogStr("Wollen wir nicht etwas mitnehmen?")


dialogId("tru-m-vzit1", "font_small", "What about taking some treasure with us?")
dialogStr("Wie wäre es, wenn wir ein paar Schätze mitnehmen?")


dialogId("tru-m-vzit2", "font_small", "Aren`t you sorry to leave all this treasure behind?")
dialogStr("Tut es dir nicht leid, die ganzen Schätze zurückzulassen?")


dialogId("tru-v-vzit0", "font_big", "We will be glad if we manage to get out ourselves.")
dialogStr("Wir werden froh sein, wenn wir selbst hier rauskommen.")


dialogId("tru-v-vzit1", "font_big", "Don`t forget our mission.")
dialogStr("Vergiss nicht unseren Auftrag.")


dialogId("tru-v-vzit2", "font_big", "The treasure would only hinder us.")
dialogStr("Ein Schatz würde uns nur behindern.")


dialogId("tru-v-zrak", "font_big", "All this glinting is a sight for the eyes.")
dialogStr("All dieses Glitzern ist eine Augenweide.")


dialogId("tru-m-trpyt", "font_small", "Everything here gleams so. It makes me dizzy.")
dialogStr("Hier schimmert alles so. Mir wird ganz schwindelig.")

==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/chest/dialogs_de.lua <==

dialogId("tru-v-nasly", "font_big", "So we have finally found it.")
dialogStr("Haben wir ihn endlich gefunden.")


dialogId("tru-m-co", "font_small", "What?")
dialogStr("Was?")


dialogId("tru-v-poklad", "font_big", "Captain Silver’s treasure, of course.")
dialogStr("Na Kapitän Silvers Schatz!")


dialogId("tru-v-gral", "font_big", "The Holy Grail, of course.")
dialogStr("Na den heiligen Gral!")


dialogId("tru-v-vkupe", "font_big", "It’s neatly in one place: the treasure and the Grail.")
dialogStr("Alles schön auf einem Haufen: der Schatz und der Gral.")


dialogId("tru-m-zrada", "font_small", "I think it’s much too easy to be true.")
dialogStr("Ich glaube, das ist zu einfach, um war zu sein.")


dialogId("tru-m-oznamit", "font_small", "I think that if it really was our goal, the game would let the player know.")
dialogStr("Ich denke, wenn das wirklich unser Ziel wäre, würde das Programm es den Spieler wissen lassen.")


dialogId("tru-v-stacit", "font_big", "But I have let them know. That could be enough.")
dialogStr("Aber ich habe es ihn wissen lassen. Das könnte reichen.")


dialogId("tru-m-zpochybnit", "font_small", "But I have casted doubts on it. This could confuse them.")
dialogStr("Aber ich habe es angezweifelt. Das könnte ihn durcheinanderbringen.")


dialogId("tru-v-nejspis", "font_big", "Well, all right. PROBABLY this is not what we are looking for.")
dialogStr("Hmm, na gut. WAHRSCHEINLICH ist das nicht, wonach wir suchen.")


dialogId("tru-m-nejistota", "font_small", "That's better. There remains a bit of uncertainty.")
dialogStr("So ist es besser. Das hinterlässt eine bisschen Unsicherheit.")


dialogId("tru-m-truhla0", "font_small", "Couldn’t we close that chest?")
dialogStr("Können wir die Truhe nicht zumachen?")


dialogId("tru-m-truhla1", "font_small", "What if we try to close that chest?")
dialogStr("Wollen wir versuchen, die Truhe zu schließen?")


dialogId("tru-v-truhla0", "font_big", "It would be much easier with the chest closed.")
dialogStr("Mit der geschlossenen Truhe wäre es viel einfacher.")


dialogId("tru-v-truhla1", "font_big", "Try to push its lid.")
dialogStr("Versuch mal, den Deckel zu bewegen.")


dialogId("tru-m-vzit0", "font_small", "Won’t we take something with us?")
dialogStr("Wollen wir nicht etwas mitnehmen?")


dialogId("tru-m-vzit1", "font_small", "What about taking some treasure with us?")
dialogStr("Wie wäre es, wenn wir ein paar Schätze mitnehmen?")


dialogId("tru-m-vzit2", "font_small", "Aren’t you sorry to leave all this treasure behind?")
dialogStr("Tut es dir nicht leid, die ganzen Schätze zurückzulassen?")


dialogId("tru-v-vzit0", "font_big", "We will be glad if we manage to get out ourselves.")
dialogStr("Wir werden froh sein, wenn wir selbst hier rauskommen.")


dialogId("tru-v-vzit1", "font_big", "Don’t forget our mission.")
dialogStr("Vergiss nicht unseren Auftrag.")


dialogId("tru-v-vzit2", "font_big", "The treasure would only hinder us.")
dialogStr("Ein Schatz würde uns nur behindern.")


dialogId("tru-v-zrak", "font_big", "All this glinting is a sight for the eyes.")
dialogStr("All dieses Glitzern ist eine Augenweide.")


dialogId("tru-m-trpyt", "font_small", "Everything here gleams so. It makes me dizzy.")
dialogStr("Hier schimmert alles so. Mir wird ganz schwindelig.")
